#######################
Electron Cutout Factors
#######################

*******
Summary
*******

.. automodule:: pymedphys.electronfactors
    :no-members:



***
API
***

.. autofunction:: pymedphys.electronfactors.parameterise_insert

.. autofunction:: pymedphys.electronfactors.spline_model

.. autofunction:: pymedphys.electronfactors.calculate_deformability

.. autofunction:: pymedphys.electronfactors.spline_model_with_deformability

.. autofunction:: pymedphys.electronfactors.calculate_percent_prediction_differences

.. autofunction:: pymedphys.electronfactors.visual_alignment_of_equivalent_ellipse
